==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DashboardIndicator.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DashboardIndicator
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DashboardIndicator extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DashboardIndicator> {

    /** DashboardIndicator attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");

            return list;
        }
    }

    /** Field attributes */
    public static DashboardIndicatorFieldAttributes FieldAttributes=new DashboardIndicatorFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DashboardIndicatorFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * indicator relation.
         *
         * @return the indicator bean relations attributes.
         */
        public Indicator.Relations indicator()
        {
            Indicator c = new Indicator();
            return c.new Relations(this.buildPath("indicator"));
        }

        /**
         * dashboard relation.
         *
         * @return the dashboard bean relations attributes.
         */
        public Dashboard.Relations dashboard()
        {
            Dashboard c = new Dashboard();
            return c.new Relations(this.buildPath("dashboard"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
    }

    /** The dummy obj. */
    private static DashboardIndicator dummyObj=new DashboardIndicator();

    /**
     * Get DashboardIndicator Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DashboardIndicator> getDataSet()
    {
        return new HibernateDataSet<DashboardIndicator>(DashboardIndicator.class, HibernateUtil.getSessionFactory("DIFRepository"),
            DashboardIndicator.getPKFieldListAsString(), DashboardIndicator.FieldAttributes);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DashboardIndicator> getDataSetInstance()
    {
        return new DashboardIndicator().getDataSet();
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("indicator".equalsIgnoreCase(attributeName))
            return indicator;
        if("dashboard".equalsIgnoreCase(attributeName))
            return dashboard;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("indicator".equalsIgnoreCase(attributeName))
            indicator =(Indicator)attributeValue;
        if("dashboard".equalsIgnoreCase(attributeName))
            dashboard =(Dashboard)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** indicator private attribute */
    private Indicator indicator;

    /** dashboard private attribute */
    private Dashboard dashboard;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {

        Object value = getAttribute(attributeName);

        if (value == null)
            return "";
        else {
            return value.toString().trim();
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DashboardIndicator() {
    }


    /**
     * full constructor
	 *
     * @param indicator the indicator
     * @param dashboard the dashboard
     */
    public DashboardIndicator(Indicator indicator, Dashboard dashboard) {
        this.indicator = indicator;
        this.dashboard = dashboard;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * indicator getter method
     *
     * @return indicator method
     */
    public Indicator getIndicator() {
        return this.indicator;
    }
    
    /**       
     * indicator setter method
     *
     * @param indicator the indicator
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setIndicator(Indicator indicator) {
        this.indicator = indicator;
        
        return this;
    }
    /**       
     * dashboard getter method
     *
     * @return dashboard method
     */
    public Dashboard getDashboard() {
        return this.dashboard;
    }
    
    /**       
     * dashboard setter method
     *
     * @param dashboard the dashboard
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setDashboard(Dashboard dashboard) {
        this.dashboard = dashboard;
        
        return this;
    }

    /**
     * Creates a String representation of the DashboardIndicator object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DashboardIndicator object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DashboardIndicator other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DashboardIndicator getProxy(Session session, Long id)
    {
        return(DashboardIndicator)session.load(DashboardIndicator.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DashboardIndicator getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DashboardIndicator result = (DashboardIndicator)session.load(DashboardIndicator.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DashboardIndicator getInstance(Session session, Long id)
    {
        return(DashboardIndicator)session.get(DashboardIndicator.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DashboardIndicator getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory("DIFRepository").getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DashboardIndicator result = (DashboardIndicator)session.get(DashboardIndicator.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/DashboardIndicator.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;


import java.util.ArrayList;
import java.util.List;
import org.hibernate.Session;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.utils.AbstractBeanRelationsAttributes;
import pt.digitalis.dif.model.utils.IBeanAttributesDataSet;

/**
 * DashboardIndicator
* Generated on ORM Generator
* DIF build process for the Model layer
*
*/
@SuppressWarnings("serial")
public class DashboardIndicator extends AbstractBeanRelationsAttributes implements java.io.Serializable, IBeanAttributesDataSet<DashboardIndicator> {

    /**
    * Constant with the session factory ID
    */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /** DashboardIndicator attributes enumeration */
    public static class Fields
    {
        /** id column */
        public static final String ID ="id";

        /**
         * List of existing fields
         *
         * @return list of field names
         */
        public static List<String> values()
        {
            ArrayList<String> list = new ArrayList<String>();
            list.add("id");

            return list;
        }
    }

    /** Field attributes */
    public static DashboardIndicatorFieldAttributes FieldAttributes=new DashboardIndicatorFieldAttributes();

    /**
    * @return the field attributes definitions
    */
    @Override public DashboardIndicatorFieldAttributes getDefinitions()
    {
        return FieldAttributes;
    }

    /**
     * The Class Relations.
     */
    public class Relations extends AbstractBeanRelationsAttributes.AbstractRelations
    {

        /**
        * Instantiates a new relations.
        *
        * @param currentPath the current path
        */
        public Relations(String currentPath)
        {
            super(currentPath);
        }
        /**
         * indicator relation.
         *
         * @return the indicator bean relations attributes.
         */
        public Indicator.Relations indicator()
        {
            Indicator c = new Indicator();
            return c.new Relations(this.buildPath("indicator"));
        }

        /**
         * dashboard relation.
         *
         * @return the dashboard bean relations attributes.
         */
        public Dashboard.Relations dashboard()
        {
            Dashboard c = new Dashboard();
            return c.new Relations(this.buildPath("dashboard"));
        }

        /**
         * the ID path.
         *
         * @return the path
         */
        public String ID()
        {
            return buildPath(Fields.ID);
        }
    }

    /** The dummy obj. */
    private static DashboardIndicator dummyObj=new DashboardIndicator();

    /**
     * Get DashboardIndicator Relations .
     *
     * @return the relations
     */
    public static Relations FK()
    {
        return dummyObj.new Relations(null);
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public IDataSet<DashboardIndicator> getDataSet()
    {
        return getDataSetInstance();
    }

    /**
    * Gets a new dataSet object for this bean
    *
    * @return the dataSet
    */
    public static IDataSet<DashboardIndicator> getDataSetInstance()
    {
        return new HibernateDataSet<DashboardIndicator>(DashboardIndicator.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
            DashboardIndicator.getPKFieldListAsString(), DashboardIndicator.FieldAttributes);
    }

    /**
    * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeNoGraphNavigation(java.lang.String)
    */
    @Override protected Object getAttributeNoGraphNavigation(String attributeName)
    {
        if("id".equalsIgnoreCase(attributeName))
            return id;
        if("indicator".equalsIgnoreCase(attributeName))
            return indicator;
        if("dashboard".equalsIgnoreCase(attributeName))
            return dashboard;

        return null;
    }

    /**
    * @see pt.digitalis.utils.common.IBeanAttributes#setAttribute(java.lang.String, java.lang.Object)
    */
    public void setAttribute(String attributeName,Object attributeValue)
    {
        if("id".equalsIgnoreCase(attributeName))
            id =(Long)attributeValue;
        if("indicator".equalsIgnoreCase(attributeName))
            indicator =(Indicator)attributeValue;
        if("dashboard".equalsIgnoreCase(attributeName))
            dashboard =(Dashboard)attributeValue;
    }

    // Fields

    /** id private attribute */
    private Long id;

    /** indicator private attribute */
    private Indicator indicator;

    /** dashboard private attribute */
    private Dashboard dashboard;

    /** The pojo's primary key field list names */
    private static List<String> pkFieldList;

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
     public synchronized static List<String> getPKFieldList()
     {
         if (pkFieldList == null)
         {
             pkFieldList = new ArrayList<String>();
             pkFieldList.add("id");
         }

         return pkFieldList;
     }

    /**
     * Get the table fields that compose the PK as a comma separated field name list
     *
     * @return the PK field list as a string
     */
     public static String getPKFieldListAsString()
     {
         StringBuffer buffer = new StringBuffer();

         for (int i = 0; i < getPKFieldList().size(); i++)
         {
             if (i != 0)
                 buffer.append(",");

             buffer.append(getPKFieldList().get(i));
         }

         return buffer.toString();
     }

    /**
     * Gets description field.
     *
     * @return the description field
     */
    @Override
    public String getDescriptionField()
    {
        return FieldAttributes.getDescriptionField();
    }

    /**
     * Get the table fields that compose the PK
     *
     * @return the PK field list
     */
    @Override
    public List<String> getPKFields()
    {
        return getPKFieldList();
    }

    /**
     * Is composite PK.
     *
     * @return the boolean
     */
    @Override
    public boolean isCompositePK()
    {
        return this.getPKFieldList().size() > 1;
    }

    /**
     * @see pt.digitalis.dif.model.utils.AbstractBeanAttributes#getAttributeAsString(java.lang.String)
     */
     @Override
     public String getAttributeAsString(String attributeName)
     {
        if (attributeName.contains("."))
        {
            return this.getAttributeAsStringParseBeanPath(attributeName);
        }
        else
        {
            Object value = getAttribute(attributeName);

            if (value == null)
                return "";
            else {
                return value.toString().trim();
            }
        }
     }

    // Constructors

    /**
     * default constructor
     */
    public DashboardIndicator() {
    }


    /**
     * full constructor
	 *
     * @param indicator the indicator
     * @param dashboard the dashboard
     */
    public DashboardIndicator(Indicator indicator, Dashboard dashboard) {
        this.indicator = indicator;
        this.dashboard = dashboard;
    }

    // Property accessors
    
    /**       
     * id getter method
     *
     * @return id method
     */
    public Long getId() {
        return this.id;
    }
    
    /**       
     * id setter method
     *
     * @param id the id
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setId(Long id) {
        this.id = id;
        
        return this;
    }
    /**       
     * indicator getter method
     *
     * @return indicator method
     */
    public Indicator getIndicator() {
        return this.indicator;
    }
    
    /**       
     * indicator setter method
     *
     * @param indicator the indicator
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setIndicator(Indicator indicator) {
        this.indicator = indicator;
        
        return this;
    }
    /**       
     * dashboard getter method
     *
     * @return dashboard method
     */
    public Dashboard getDashboard() {
        return this.dashboard;
    }
    
    /**       
     * dashboard setter method
     *
     * @param dashboard the dashboard
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setDashboard(Dashboard dashboard) {
        this.dashboard = dashboard;
        
        return this;
    }

    /**
     * indicator id getter method
     *
     * @return indicator id method
     */
    public Long getIndicatorId() {
        if (this.indicator == null)
            return null;
        else
            return this.indicator.getId();
    }

    /**
     * Indicator proxy setter method from id.
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setIndicatorProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.indicator = null;
        else
            this.indicator = Indicator.getProxy(id);

        return this;
    }

    /**
     * Indicator instance setter method from id.
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setIndicatorInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.indicator = null;
        else
            this.indicator = Indicator.getInstance(id);

        return this;
    }
    /**
     * dashboard id getter method
     *
     * @return dashboard id method
     */
    public Long getDashboardId() {
        if (this.dashboard == null)
            return null;
        else
            return this.dashboard.getId();
    }

    /**
     * Dashboard proxy setter method from id.
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setDashboardProxyFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dashboard = null;
        else
            this.dashboard = Dashboard.getProxy(id);

        return this;
    }

    /**
     * Dashboard instance setter method from id.
     *
     * @return DashboardIndicator modified instance
     */
    public DashboardIndicator setDashboardInstanceFromId(Long id)
    {
        if (id == null || id.equals(-1L))
            this.dashboard = null;
        else
            this.dashboard = Dashboard.getInstance(id);

        return this;
    }

    /**
     * Creates a String representation of the DashboardIndicator object
     *
     * @return the compiled String
     */
    @Override
    public String toString() {
	    StringBuffer buffer = new StringBuffer();

        buffer.append(getClass().getName()).append("@").append(Integer.toHexString(hashCode())).append(" [");

        buffer.append("id").append("='").append(getId()).append("' ");			
        buffer.append("]");
      
        return buffer.toString();
    }

    /**
     * Compares the String representation of the DashboardIndicator object
     *
     * @param other The object to compare to
     *
     * @return true of the objects are equal
     */
    public boolean equals(DashboardIndicator other) {
        	return this.toString().equals(other.toString());
    }
    /**
     * @see pt.digitalis.utils.common.IBeanAttributes#setAttributeFromString(java.lang.String, java.lang.String)
     */
    public void setAttributeFromString(String attributeName, String attributeValue) {
        if ("id".equalsIgnoreCase(attributeName))
            this.id = Long.valueOf(attributeValue);

    }


    /**
     * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
     *
     * @param session the session
     * @param id      the id
     *
     * @return the proxy
     */
    public static DashboardIndicator getProxy(Session session, Long id)
    {
        return(DashboardIndicator)session.load(DashboardIndicator.class,id);
    }

    /**
    * Instanciates an Hibernate proxy data object (does not load it from the database, provides lazy load for that)
    *
    * @param id      the id
    *
    * @return the proxy
    */
    public static DashboardIndicator getProxy(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DashboardIndicator result = (DashboardIndicator)session.load(DashboardIndicator.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }


    /**
     * Instanciates an Hibernate data object
     *
     * @param session the session
     * @param id      the id
     *
     * @return the instance
     */
    public static DashboardIndicator getInstanceForSession(Session session, Long id)
    {
        return(DashboardIndicator)session.get(DashboardIndicator.class,id);
    }

    /**
    * Instanciates an Hibernate data object
    *
    * @param id      the id
    *
    * @return the instance
    */
    public static DashboardIndicator getInstance(Long id)
    {
        Session session = HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME).getCurrentSession();
        boolean wasActive = session.getTransaction().isActive();

        if (!wasActive)
            session.beginTransaction();

        DashboardIndicator result = (DashboardIndicator)session.get(DashboardIndicator.class,id);

        if (!wasActive)
            session.getTransaction().commit();

        return result;
    }

}
